==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/elb/kotlin/inputs/LoadBalancerPolicyPolicyAttributeArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.elb.kotlin.inputs

import com.pulumi.aws.elb.inputs.LoadBalancerPolicyPolicyAttributeArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property name
 * @property value
 */
public data class LoadBalancerPolicyPolicyAttributeArgs(
    public val name: Output<String>? = null,
    public val `value`: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.elb.inputs.LoadBalancerPolicyPolicyAttributeArgs> {
    override fun toJava(): com.pulumi.aws.elb.inputs.LoadBalancerPolicyPolicyAttributeArgs =
        com.pulumi.aws.elb.inputs.LoadBalancerPolicyPolicyAttributeArgs.builder()
            .name(name?.applyValue({ args0 -> args0 }))
            .`value`(`value`?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LoadBalancerPolicyPolicyAttributeArgs].
 */
@PulumiTagMarker
public class LoadBalancerPolicyPolicyAttributeArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("ylvsmqfgbmkeqpjf")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value
     */
    @JvmName("pkdcfpoqqvpymdeh")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value
     */
    @JvmName("xvdcrlqrjtphgebf")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value
     */
    @JvmName("fnvcmkvakyivoqho")
    public suspend fun `value`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): LoadBalancerPolicyPolicyAttributeArgs =
        LoadBalancerPolicyPolicyAttributeArgs(
            name = name,
            `value` = `value`,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/elb/kotlin/inputs/LoadBalancerPolicyPolicyAttributeArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.elb.kotlin.inputs

import com.pulumi.aws.elb.inputs.LoadBalancerPolicyPolicyAttributeArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property name
 * @property value
 */
public data class LoadBalancerPolicyPolicyAttributeArgs(
    public val name: Output<String>? = null,
    public val `value`: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.elb.inputs.LoadBalancerPolicyPolicyAttributeArgs> {
    override fun toJava(): com.pulumi.aws.elb.inputs.LoadBalancerPolicyPolicyAttributeArgs =
        com.pulumi.aws.elb.inputs.LoadBalancerPolicyPolicyAttributeArgs.builder()
            .name(name?.applyValue({ args0 -> args0 }))
            .`value`(`value`?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LoadBalancerPolicyPolicyAttributeArgs].
 */
@PulumiTagMarker
public class LoadBalancerPolicyPolicyAttributeArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("ysjiuymvholftdrj")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value
     */
    @JvmName("eqpdedrilujqnfem")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value
     */
    @JvmName("ccbfonwjffuwitdo")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value
     */
    @JvmName("arxpoukxtmateurr")
    public suspend fun `value`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): LoadBalancerPolicyPolicyAttributeArgs =
        LoadBalancerPolicyPolicyAttributeArgs(
            name = name,
            `value` = `value`,
        )
}
